@@ -411,8 +411,8 @@ search_button_clicked (GtkButton *button,
 
   append_entry_completion (data);
 
-  const gchar *needle = gtk_entry_get_text
-    ((GtkEntry*) o->entry);
+  const gchar *needle =
+    gtk_entry_get_text((GtkEntry*) o->entry);
 
   // clear previous results
   model = gtk_tree_view_get_model (GTK_TREE_VIEW(o->song_list));
@@ -473,6 +473,7 @@ run_search (GtkEntry *entry,
     G_UNLOCK (search_active);
     return;
   }
+  G_UNLOCK (search_active);
 
   search_button_clicked (NULL, data);
 }
@@ -514,12 +515,12 @@ create_loader_page (msid_search_plugin *plugin,
    */
 
   // TODO - fix bugs with pannable area
-  scroll_win = hildon_pannable_area_new();
-  /*  
+  //scroll_win = hildon_pannable_area_new();
+
   scroll_win = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(scroll_win),
   				  GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-  */
+
   search_button = create_ui_button ("search");
   search_entry  = gtk_entry_new();
 
@@ -565,8 +566,7 @@ create_loader_page (msid_search_plugin *plugin,
 		    G_CALLBACK(run_search), &s_widgets);
 
   g_signal_connect (G_OBJECT(search_button), "clicked",
-		    G_CALLBACK(search_button_clicked),
-		    &s_widgets);
+		    G_CALLBACK(run_search), &s_widgets);
 
   g_signal_connect (G_OBJECT(song_list),
 		    "row-activated",
