@@ -30,6 +30,8 @@
 #include "config_tab.h"
 #include "image_tab.h"
 
+#include "paths.h"
+
 #include "plugins/driver_iface.h"
 #include "plugins/search_iface.h"
 #include "plugins/debug.h"
@@ -85,12 +87,8 @@ static int SUBSONG = 1;
 
 char download_path[256];
 
-#define PLUGIN_FILE_PATH "/usr/lib/msid"
-#define CONFIG_FILE_PATH "/usr/share/msid"
-#define CONFIG_FILE_FULL_PATH CONFIG_FILE_PATH "/msid_config.ini"
-
 /* these settings are used by default *only* if everything else fails */
-#define DEFAULT_AUDIO_PLUGIN "libmsid_esd.so"
+#define DEFAULT_AUDIO_PLUGIN "libmsid_pulse.so"
 #define DEFAULT_SEARCH_PLUGIN "libmsid_c64org.so"
 static const gchar default_config[] =
   "[msid_config]\naudio_plugin = " DEFAULT_AUDIO_PLUGIN "\n search_plugin = " DEFAULT_SEARCH_PLUGIN "\n";
@@ -864,8 +862,11 @@ static void
 hide_to_panel (GtkMenuItem *menuitem, gpointer data)
 {
   GtkStatusIcon *icon;
+  char buffer[256];
 
-  icon = gtk_status_icon_new_from_file ("/usr/share/pixmaps/msid.png");
+  snprintf(buffer, 256, "%s/msid.png", ICON_FILE_PATH);
+
+  icon = gtk_status_icon_new_from_file (buffer);
 
   g_signal_connect (G_OBJECT(icon), "activate",
 		    G_CALLBACK(show_from_panel), NULL);
@@ -952,6 +953,8 @@ show_about_dialog (GtkMenuItem *menuitem, gpointer data)
   GtkWidget *hbox;
   GtkWidget *logo;
 
+  char buffer[256];
+
   char txt[] = "MSID uses libsidplay1, a SID chip emulator by Michael Schwendt. MSID UI was programmed by lemody@c64.org\n\nMany thanks and respect to the admins of c64.org and c64.com for letting MSID use their resources.";
 
   GtkWidget *dialog = gtk_dialog_new_with_buttons ("About",
@@ -964,7 +967,9 @@ show_about_dialog (GtkMenuItem *menuitem, gpointer data)
 
   hbox = gtk_hbox_new (FALSE, 8);
 
-  logo = gtk_image_new_from_file ("/usr/share/msid/msidlogo.png");
+  snprintf(buffer, 256, "%s/msidlogo.png", CONFIG_FILE_PATH);
+
+  logo = gtk_image_new_from_file (buffer);
 
   info = gtk_label_new ("");
   gtk_label_set_markup (GTK_LABEL(info), txt);
@@ -1016,8 +1021,6 @@ show_config_dialog (GtkMenuItem *menuitem, gpointer data)
   GtkWidget *dialog = gtk_dialog_new_with_buttons ("Preferences",
 						   GTK_WINDOW(app_window),
 						   (GtkDialogFlags) (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
-						   GTK_STOCK_CLOSE,
-						   GTK_RESPONSE_ACCEPT,
 						   NULL);
 #ifndef HILDON
   gtk_window_set_position (GTK_WINDOW(dialog), GTK_WIN_POS_CENTER_ON_PARENT);
@@ -1136,9 +1139,11 @@ int main (int argc, char **argv)
     *loader_label,
     *image_label,
 
+    /*
     *player_button,
     *loader_button,
     *image_button,
+    */
 
     *player_page,
     *loader_page,
@@ -1351,16 +1356,16 @@ int main (int argc, char **argv)
 
   //#define STACK
 #ifdef STACK
-  player_button = create_huge_button("Player");
-  loader_button = create_huge_button("Loader");
-  image_button = create_huge_button("Slideshow");
+  stack_player_button = create_huge_button("Player");
+  stack_loader_button = create_huge_button("Loader");
+  stack_image_button = create_huge_button("Slideshow");
 
 #define UI_PAD 64
   mother_container = gtk_hbox_new (TRUE, UI_PAD);
 
-  gtk_box_pack_start (GTK_BOX(mother_container), player_button, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX(mother_container), loader_button, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX(mother_container), image_button, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX(mother_container), stack_player_button, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX(mother_container), stack_loader_button, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX(mother_container), stack_image_button, FALSE, FALSE, 0);
 
   player_window = hildon_stackable_window_new();
   loader_window = hildon_stackable_window_new();
@@ -1376,9 +1381,9 @@ int main (int argc, char **argv)
 
   printf("player window pointer %p!\n", player_window);
 
-  g_signal_connect (G_OBJECT(player_button), "clicked", G_CALLBACK (show_window), player_window);
-  g_signal_connect (G_OBJECT(loader_button), "clicked", G_CALLBACK (show_window), loader_window);
-  g_signal_connect (G_OBJECT(image_button),  "clicked", G_CALLBACK (show_window), image_window);
+  g_signal_connect (G_OBJECT(stack_player_button), "clicked", G_CALLBACK (show_window), player_window);
+  g_signal_connect (G_OBJECT(stack_loader_button), "clicked", G_CALLBACK (show_window), loader_window);
+  g_signal_connect (G_OBJECT(stack_image_button),  "clicked", G_CALLBACK (show_window), image_window);
 
 
 #endif
@@ -1452,6 +1457,8 @@ int main (int argc, char **argv)
    * signal-handlers for extern objects
    */
 
+
+
   g_signal_connect (G_OBJECT (player_song_list), "key-release-event",
                     G_CALLBACK (key_on_selection), (gpointer) &machine);
 
@@ -1474,10 +1481,10 @@ int main (int argc, char **argv)
   g_signal_connect (G_OBJECT (hvsc_path_selection_button), "clicked",
 		    G_CALLBACK (select_hvsc_path), NULL);
 
+  // FIXME - !!!
   g_signal_connect (G_OBJECT (image_button), "clicked",
 		    G_CALLBACK (load_screenshot), NULL);
 
-
   g_signal_connect (G_OBJECT (app_window), "key-release-event",
                     G_CALLBACK (msid_on_key_release_event), NULL);
 
